----------------
-- TotemHenge --
----------------

TotemHenge = Henge:NewModule("TotemHenge")
TotemHenge.fullname = "TotemHenge"
TotemHenge.icon     = "icon"
local ML = AceLibrary("AceLocale-2.2"):new("TotemHenge")
local SL = AceLibrary("Babble-Spell-2.2")
local TS = AceLibrary("TalentShow-1.0")

function TotemHenge:Test()
	local _, pClass = UnitClass("player")
	return (pClass == "SHAMAN")
end

function TotemHenge:Load()
	-- Set up variables
	self:SetupDB({
		["profile"] = {
			--[[
			ShowTotemMsg = false,
			ShowResMsg = false,
			ShowWeapBuffMsg = false,
			TotemMsg = {
				stoneskin = "Rock solid, baby.",
				earthbind = "Hold it right there!",
				stoneclaw = "You wanna piece of this?",
				strength = "/flex",
				tremor = "Stay alert, people.",
				searing = "Burn, baby, burn!",
				firenova = "You might want to stand back.",
				frostresist = "Brr, everyone huddle up close to me.",
				magma = "Some like it hot, others not.",
				flametongue = "Pft.  Who needs enchanting?",
				healing = "Feel the cool waters revive you.",
				poisonclean = "You look sick.",
				manaspring = "Revitalize the body and mind.",
				diseaseclean = "You ought to wash that before it gets infected.",
				fireresist = "Is it hot in here, or is it just me?",
				manatide = "Tide's up.",
				grounding = "STOP!  Totem time.",
				natureresist = "Here's your rubber boots.",
				windfury = "Third strike, you're out!",
				sentry = "Keep an eye out.",
				windwall = "Anyone else feel a draft?",
				graceofair = "Quick as the winds.",
				tranquilair = "Calm down, breath in, breath out."
			},
			ResMsg = "We have a man down!  Medic!",
			WeapBuffMsg = {
				rockbiter = "Feel the might of my rock'o'stick!",
				flametongue = "Feel the burn!",
				frostbrand = "I like mine chilled, on the rocks.",
				windfury = "What is the sound of one mace repeatedly bludgeoning?"
			}
			]]--
		},
		["char"] = {}
	})
	local spell = {
	-- Earth Totems
		["stoneskin"]      =         SL["Stoneskin Totem"],
		["earthbind"]      =         SL["Earthbind Totem"],
		["stoneclaw"]      =         SL["Stoneclaw Totem"],
		["strength"]       = SL["Strength of Earth Totem"],
		["tremor"]         =            SL["Tremor Totem"],
	-- Fire Totems
		["searing"]        =           SL["Searing Totem"],
		["firenova"]       =         SL["Fire Nova Totem"],
		["frostresist"]    =  SL["Frost Resistance Totem"],
		["magma"]          =             SL["Magma Totem"],
		["flametonguet"]   =       SL["Flametongue Totem"],
		["towrath"]        =          SL["Totem of Wrath"],
	-- Water Totems
		["healing"]        =    SL["Healing Stream Totem"],
		["poisonclean"]    =  SL["Poison Cleansing Totem"],
		["manaspring"]     =       SL["Mana Spring Totem"],
		["diseaseclean"]   = SL["Disease Cleansing Totem"],
		["fireresist"]     =   SL["Fire Resistance Totem"],
		["manatide"]       =         SL["Mana Tide Totem"],
	-- Air Totems
		["grounding"]      =         SL["Grounding Totem"],
		["natureresist"]   = SL["Nature Resistance Totem"],
		["windfuryt"]      =          SL["Windfury Totem"],
		["sentry"]         =            SL["Sentry Totem"],
		["windwall"]       =          SL["Windwall Totem"],
		["graceofair"]     =      SL["Grace of Air Totem"],
		["tranquilair"]    =      SL["Tranquil Air Totem"],
	-- Weapon Buffs
		["rockbiterw"]     =        SL["Rockbiter Weapon"],
		["flametonguew"]   =      SL["Flametongue Weapon"],
		["frostbrandw"]    =       SL["Frostbrand Weapon"],
		["windfuryw"]      =         SL["Windfury Weapon"],
	-- Shields
		["lshield"]        =        SL["Lightning Shield"],
		["eshield"]        =            SL["Earth Shield"],
	-- Cures
		["curepsn"]        =             SL["Cure Poison"],
		["curedis"]        =            SL["Cure Disease"],
	-- Heals
		["healwave"]       =            SL["Healing Wave"],
		["lesserhw"]       =     SL["Lesser Healing Wave"],
		["chainheal"]      =              SL["Chain Heal"],
	-- Shocks
		["earthshock"]     =             SL["Earth Shock"],
		["flameshock"]     =             SL["Flame Shock"],
		["frostshock"]     =             SL["Frost Shock"],
	-- Lightning
		["litbolt"]        =          SL["Lightning Bolt"],
		["chainlit"]       =         SL["Chain Lightning"],
	-- Buffs
		["waterbreath"]    =         SL["Water Breathing"],
		["waterwalk"]      =           SL["Water Walking"],
	-- Miscellaneous
		["ancspirit"]      =        SL["Ancestral Spirit"],
		["ghostwolf"]      =              SL["Ghost Wolf"],
		["farsight"]       =               SL["Far Sight"],
		["astralrecall"]   =           SL["Astral Recall"],
		["purge"]          =                   SL["Purge"],
		["reincarnation"]  =           SL["Reincarnation"]
	}
	for k, v in pairs(spell) do
		HengeAction:Add({
			["id"] = k,
			["type"] = 'spell',
			["name"] = v,
			["spell"] = v
		})
	end
	HengeAction:Add({
		["id"] = "enwatersp",
		["type"] = 'item',
		["itemid"] = 20503
	})
	HengeSphere:AddData({
		["id"]   = "mana",
		["name"] = ML["Mana"],
		["func"] = function()
			return UnitMana("player"), UnitManaMax("player")
		end,
		["event"] = "UNIT_MANA",
		["arg1"] = "player"
	})
	HengeCounter:Add({
		["id"] = "reincarnation",
		["type"] = 'spell',
		["spell"] = SL["Reincarnation"]
	})
	HengeSphere:AddData({
		["id"]   = "reincarnation",
		["name"] = ML["Reincarnation Cooldown"],
		["textfunc"] = function()
			local reinctimer = HengeCounter:Get("reincarnation")
			local time, _ = reinctimer:GetCount()
			return time, "timer"
		end,
		["gfxfunc"] = function()
			local reinctimer = HengeCounter:Get("reincarnation")
			local time, _ = reinctimer:GetCount()
			return self:GetReincTime() - (time or 0), self:GetReincTime()
		end,
		["counter"] = "reincarnation",
		["arg1"] = nil
	})
	local data = {
		{
			["id"]   = "weapbuff",
			["name"] = ML["Weapon Buff"],
			["pos"]  = 315,
			["icon"] = "action",
			["menu"] = {
				[1] = "rockbiterw",
				[2] = "flametonguew",
				[3] = "frostbrandw",
				[4] = "windfuryw"
			}
		},
		{
			["id"]     = "earthtotem",
			["name"]   = ML["Earth Totem"],
			["pos"]    = 140,
			["icon"] = "action",
			["menu"] = {
				[1] = "stoneskin",
				[2] = "earthbind",
				[3] = "stoneclaw",
				[4] = "strength",
				[5] = "tremor"
			}
		},
		{
			["id"]     = "firetotem",
			["name"]   = ML["Fire Totem"],
			["pos"]    = 105,
			["icon"] = "action",
			["menu"] = {
				[1] = "searing",
				[2] = "firenova",
				[3] = "frostresist",
				[4] = "magma",
				[5] = "flametonguet",
				[6] = "towrath"
			}
		},
		{
			["id"]     = "watertotem",
			["name"]   = ML["Water Totem"],
			["pos"]    = 70,
			["icon"] = "action",
			["menu"] = {
				[1] = "healing",
				[2] = "poisonclean",
				[3] = "manaspring",
				[4] = "diseaseclean",
				[5] = "fireresist",
				[6] = "manatide",
				[7] = "enwatersp"
			}
		},
		{
			["id"]     = "airtotem",
			["name"]   = ML["Air Totem"],
			["pos"]    = 35,
			["icon"] = "action",
			["menu"] = {
				[1] = "grounding",
				[2] = "natureresist",
				[3] = "windfuryt",
				[4] = "sentry",
				[5] = "windwall",
				[6] = "graceofair",
				[7] = "tranquilair"
			}
		}
	}
	for k, v in ipairs(data) do
		local bdata = {
			["id"]   = v.id,
			["type"] = "menu",
			["name"] = v.name,
			["icon"] = v.icon,
			["children"] = {},
			["options"] = {
				["action"] = v.menu[1],
				["anchor"] = "sphere:Main",
				["xpos"] = 0,
				["ypos"] = 0,
				["angle"] = v.pos
			}
		}
		for num, id in ipairs(v.menu) do
			local action = HengeAction:Get(id)
			local name, desc, icon = action:ActionInfo()
			bdata.children[num] = {
				["type"] = "child",
				["id"] = id,
				["name"] = name,
				["icon"] = "action",
				["action"] = id,
				["options"] = {
				}
			}
		end
		HengeButton:Add(bdata)
	end
	HengeButton:Add({
		["id"]   = "shields",
		["type"] = "action",
		["name"] = ML["Elemental Shields"],
		["icon"] = "action:LeftButton",
		["actions"] = {
			["LeftButton"] = "lshield",
			["RightButton"] = "eshield"
		},
		["options"] = {
			["anchor"] = "sphere:Main",
			["xpos"] = 0,
			["ypos"] = 0,
			["angle"] = 350
		}
	})
end

function TotemHenge:GetReincTime()
	local tp, _ = TS:GetTalentRanks(ML["Improved Reincarnation"])
	return 3600 - (tp * 600)
end

